<?php

namespace Drupal\cmp_sirdata\Service;

use Drupal\Core\Security\TrustedCallbackInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Routing\AdminContext;

/**
 * Service for construct CMP Sirdata lazy builders.
 */
class CmpSirdataLazyBuilders implements TrustedCallbackInterface {

  /**
   * The config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The route admin context to determine whether a route is an admin one.
   *
   * @var \Drupal\Core\Routing\AdminContext
   */
  protected $adminContext;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * The settings are present by sir data configuration form.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $sirData;

  /**
   * Creates an CmpSirdataLazyBuilders object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Routing\AdminContext $admin_context
   *   The route admin context to determine whether the route is an admin one.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, AdminContext $admin_context, RendererInterface $renderer) {
    $this->configFactory = $config_factory;
    $this->adminContext = $admin_context;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  protected function supportsSirdata() {
    $this->sirData = $this->configFactory->get('cmp_sirdata.settings');
    // Do not render if not enabled or admin screens.
    if (!$this->sirData->get('enable') || $this->adminContext->isAdminRoute()) {
      return FALSE;
    }
    // Do not render if Customer Key or App Key is not configured.
    if (!$this->sirData->get('app_key') || !$this->sirData->get('customer_key')) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * Get scripts to render.
   *
   * @return array
   *   The render array.
   */
  public function lazyBuilder(): array {
    $build = [];
    if (!$this->supportsSirdata()) {
      return $build;
    }
    $customer_key = $this->sirData->get('customer_key');
    $app_key = $this->sirData->get('app_key');

    $scripts = [
      'cache' => "https://cache.consentframework.com/js/pa/{$app_key}/c/{$customer_key}/stub",
      'choices' => "https://choices.consentframework.com/js/pa/{$app_key}/c/{$customer_key}/cmp",
    ];

    foreach ($scripts as $key => $src) {
      $build[$key] = [
        '#type' => 'html_tag',
        '#tag' => 'script',
        '#attributes' => [
          'type' => 'text/javascript',
          'src' => $src,
          'referrerpolicy' => 'unsafe-url',
          'charset' => 'utf-8',
        ],
      ];
      $this->renderer->addCacheableDependency($build[$key], $this->sirData);
    }

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public static function trustedCallbacks() {
    return ['lazyBuilder'];
  }

}
